@@ -26,7 +26,7 @@ use strict;
 use warnings;
 
 package DUCK;
-my $VERSION ='0.12';
+my $VERSION ='0.13';
 my $COPYRIGHT_YEAR ='2017';
 
 my $default_user_agent='Mozilla/5.0 (X11; Linux x86_64; rv:46.0) Gecko/20100101 Firefox/46.0';
@@ -66,6 +66,7 @@ my $helpers={
 };
 
 my $website_moved_regexs;
+my $obsolete_sites;
 
 my $cli_options;
 
@@ -124,6 +125,15 @@ sub new {
        my $nc=new Config::Simple($config_file);
        my $hashes=$nc->get_block("parked_domains");
        $website_moved_regexs=$hashes->{'regexes'};
+
+       $hashes=$nc->get_block("obsolete_sites");
+       
+       if ($hashes)
+       { if ($hashes->{'regexes'})
+	 {
+	     $obsolete_sites=$hashes->{'regexes'};
+	 }
+       }
     }
 
 
@@ -550,6 +560,7 @@ sub __run_browser {
     # Looking at the results...
     my $status=0;
     my $disp=0;
+    my $is_obsolete=0;
 
  
     if ($retcode == 0) # no curl error, but maybe a http error
@@ -598,7 +609,6 @@ sub __run_browser {
 
 	}
 	my $whitelisted=0;
-
 	foreach my $whitelist_url (@website_moved_whitelist)
 	{
 	    if ( $url =~ m/$whitelist_url/i)
@@ -606,6 +616,14 @@ sub __run_browser {
 	    {$whitelisted=1;}
 
 	}
+	foreach my $obsolete_site (@$obsolete_sites)
+	{
+	    if ($url =~ m/$obsolete_site/i)
+	    {
+		$is_obsolete=1;
+	    }
+	}
+
 	if ($whitelisted == 0 && $response_body)
 	{
 	    $response_body=strip_html_comments($response_body);
@@ -645,9 +663,11 @@ sub __run_browser {
     push(@reta,$ret);
     if ($startscheme && $finalscheme)
     {	
-    
-    if ($startdomainsuffix->get_root_domain($startdomain) ne $finaldomainsuffix->get_root_domain($finaldomain))
-    {
+      my $rd_startdomainsuffix=$startdomainsuffix->get_root_domain($startdomain);
+      my $rd_finaldomainsuffix=$startdomainsuffix->get_root_domain($finaldomain);
+
+      if ($rd_startdomainsuffix && $rd_finaldomainsuffix && ($rd_startdomainsuffix ne $rd_finaldomainsuffix))
+      {
 	
 	my $ret_dom;
 	$ret_dom->{'retval'}=2;
@@ -664,6 +684,17 @@ sub __run_browser {
 	push (@reta,$ret_dom);
     } else 
     {
+
+	if ($is_obsolete==1)
+	{
+	    my $ret_obsolete;
+	    $ret_obsolete->{'retval'}=2;
+	    $ret_obsolete->{'response'}="The website/URL is known to be obsolete. Please update your links.";
+	    $ret_obsolete->{'url'}=$url;
+	    $ret_obsolete->{'certainty'}="wild-guess";
+	    push (@reta,$ret_obsolete);
+	}
+
 	if ($startscheme eq "https" and $finalscheme eq "http")
 	{
 	    
@@ -742,7 +773,7 @@ sub find_config_file()
     }
 
 
-    push (@config_dirs,"/etc/duck");
+    push (@config_dirs,"/etc");
     if (!$ENV{'XDG_CONFIG_HOME'})
     {
 	push(@config_dirs,$ENV{'HOME'}."/.config");
@@ -861,7 +892,7 @@ sub strip_html_comments()
 {
 
     my ($html)=@_;
-    my $pid=open3(\*WRITE,\*READ,\*ERR,'lynx -dump -width=2048 -stdin') or die("lynx not found!");
+    my $pid=open3(\*WRITE,\*READ,\*ERR,'lynx -cfg=/dev/null -dump -width=2048 -stdin') or die("lynx not found!");
     print WRITE $html;
     close WRITE;
     my @cleaned=<READ>;
